==> sirad_2.0-7.tar.gz: sirad/man/bccal.Rd <==
\name{bccal}
\alias{bccal}

\title{
Calibrate Bristow-Campbell model
}
\description{
Function estimates Bristow-Campbell model coefficient 'B' based on reference data
}
\usage{
bccal(lat, days, rad_mea,extraT=NULL,Tmax, Tmin, tal)
}

\arguments{
  \item{lat}{
Latitude in decimal degrees.
}
  \item{days}{
Vector of class 'Date' of length n.
}
  \item{rad_mea}{
Vector of length n containing reference (e.g. measured) solar radiation [MJm-2].
}
  \item{extraT}{
Optional. Vector of length n of extraterrestrial solar radiation [MJm-2]. If 'NULL' then it is calculated by the function. Providing extraterrestrial solar radiation speeds up the computation 
}
  \item{Tmax}{
Vector of length n containing daily maximum temperature [C]. 
}
  \item{Tmin}{
Vector of length n containing daily minumum temperature [C].
}
  \item{tal}{
Clear sky transmissivity.
}
}
\details{
Function estimates Bristow-Campbell model coefficient 'B' based on reference (e.g. measured) solar radiation data. It performs a non-linear least squeres regression.
}
\value{
\item{BCb}{Bristow-Campbell 'B' coefficient}
}
\references{
Bristow, K.L., and G.S. Campbell. 1984. On the relationship between incoming solar radiation and daily maximum and minimum temperature. Agriculture and Forest Meteorology, 31:159-166.
}
\author{
Jedrzej S. Bojanowski
}

%\note{}



\seealso{
'bc', and 'bcauto' to perform auto-calibration
}
\examples{
data(Metdata)
tmax <- Metdata$meteo$TEMP_MAX
tmin <- Metdata$meteo$TEMP_MIN
days <- Metdata$meteo$DAY
lat <- Metdata$LATITUDE
rad_mea <- Metdata$meteo$RAD_MEA
bccal(lat,days,rad_mea,extraT=NULL,tmax,tmin, tal=0.76)
}

%\keyword{}

==> sirad_2.3-1.tar.gz: sirad/man/bccal.Rd <==
\name{bccal}
\alias{bccal}

\title{
Calibrate Bristow-Campbell model
}
\description{
Function estimates Bristow-Campbell model coefficient 'B' based on reference data
}
\usage{
bccal(lat, days, rad_mea,extraT=NULL,BCc=2,Tmax, Tmin, tal)
}

\arguments{
  \item{lat}{
Latitude in decimal degrees.
}
  \item{days}{
Vector of class 'Date' of length n.
}
  \item{rad_mea}{
Vector of length n containing reference (e.g. measured) solar radiation [MJm-2].
}
  \item{extraT}{
Optional. Vector of length n of extraterrestrial solar radiation [MJm-2]. If 'NULL' then it is calculated by the function. Providing extraterrestrial solar radiation speeds up the computation 
}
  \item{BCc}{
Bristow-Campbell model coefficient 'C' usually equaled to 2.
}
  \item{Tmax}{
Vector of length n containing daily maximum temperature [C]. 
}
  \item{Tmin}{
Vector of length n containing daily minumum temperature [C].
}
  \item{tal}{
Clear sky transmissivity.
}
}
\details{
Function estimates Bristow-Campbell model coefficient 'B' based on reference (e.g. measured) solar radiation data. It performs a non-linear least squeres regression.
}
\value{
\item{BCb}{Bristow-Campbell 'B' coefficient}
}
\references{
Bristow, K.L., and G.S. Campbell. 1984. On the relationship between incoming solar radiation and daily maximum and minimum temperature. Agriculture and Forest Meteorology, 31:159-166.
}
\author{
Jedrzej S. Bojanowski
}

%\note{}



\seealso{
'bc', and 'bcauto' to perform auto-calibration
}
\examples{
data(Metdata)
tmax <- Metdata$meteo$TEMP_MAX
tmin <- Metdata$meteo$TEMP_MIN
days <- Metdata$meteo$DAY
lat <- Metdata$LATITUDE
rad_mea <- Metdata$meteo$RAD_MEA
bccal(lat,days,rad_mea,extraT=NULL,BCc=2,tmax,tmin, tal=0.76)
}

%\keyword{}
